%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%SOCAT_calcs					%
%load the mat file from "SOCAT_make_mat_file	%
%and recalulates fco2				%
%The calculations follows DOE	
%DOE is not clear whether atmosperic or equilibrator pressure should be
%used for pCO2 to fCO2 conversion. Here I have used equilibrator pressure.
%The difference is on the order of 1/100 uatm. 
%Also, it was not always possible to use equilibrator xCO2 as delta factor
%in fCO2 expression, instead the starting point for each recalculation was
%used, again the effect is very negligible. 
%
%Are Olsen, Aug 2008.				%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear


%%%%%%%%User Defined Settings%%%%%%%%%%%%%%%%%

%location of .mat files, must be subdirectory to current
matFilesLoc='matData';

%location of finished files
finFilesLoc='/Users/are/arbeid/SOCAT/Ver2Code/done/';

%location of seawater package
addpath /Users/are/Documents/MATLAB/seawater/

%%%%End of User Defined Settings%%%%%%%%%%%%%

%%%%%%%%%CALCULATIONS%%%%%%%%%%%%%%%%%%%%%%%%%

str=cat(2, 'cd ', eval('matFilesLoc')) 
eval(str)

files=dir'

for cr_i = 4:length(files) %MAY CHANGE TO 3

	load(eval('files(cr_i).name'))
	disp(eval('files(cr_i).name'))

	%kelvin temperatures
	C_temp_k=C_temp+273.15;
	C_Temperature_equi_k = C_Temperature_equi+273.15;

	%pH2Os
	pH2O=1013.25.*(exp(24.4543-67.4509.*(100./C_temp_k)-4.8489.*log(C_temp_k./100) -0.000544.*C_sal));
	pH2O_woa=1013.25.*(exp(24.4543-67.4509.*(100./C_temp_k)-4.8489.*log(C_temp_k./100) -0.000544.*woa_sss));


	pH2O_eq=1013.25.*(exp(24.4543-67.4509.*(100./C_Temperature_equi_k)...
	-4.8489.*log(C_Temperature_equi_k./100) -0.000544.*C_sal));

	pH2O_eq_woa=1013.25.*(exp(24.4543-67.4509.*(100./C_Temperature_equi_k)...
	-4.8489.*log(C_Temperature_equi_k./100)-0.000544.*woa_sss));

	%pressure, if equilibrator pressure not given, use atmospheric pressure + 3
	press=C_Pressure_equi;
	index=find(isnan(press));
	press(index)=C_Pressure_atm(index)+3;

	%NCEP pressure + 3, for calculations
	ncep_slp_eq=ncep_slp+3; 

	%ship speed	-speed to next observation
	for i = 1:length(C_lat)-1
	
	Dist=sw_dist([C_lat(i) C_lat(i+1)], [C_long(i) C_long(i+1)]); %in nm
	deltaTime=24*datenum(C_yr(i+1), C_mon(i+1), C_day(i+1),C_hh(i+1), C_mm(i+1), 0)-...
		24.*datenum(C_yr(i), C_mon(i), C_day(i), C_hh(i), C_mm(i), 0);
	speed(i)= Dist/deltaTime; %knots
	end
	speed(end+1)=speed(end);
	
	
%%%%%%%%%%%%%fCO2 CALCULATIONS%%%%%%%%%%%%

	%1. from xCO2_water_sst_wet_ppm
        	%not used
		
	%2. from xCO2_water_equi_temp_wet_ppm
            	%not used
		
	 
	%3. from xCO2_water_sst_dry_ppm%%%%%%%%%%%%
	
	%a. Reported pressures and salt
	pCO2_temp=C_xCO2_water_sst_dry_ppm.*((press-pH2O)./1013.25);						

	fCO2_insitu_from_xCO2_water_sst_dry_ppm=pCO2_temp.*exp((press./1013.25).*((-1636.75+(12.0408.*C_temp_k)...						
	-(0.0327957.*C_temp_k.^2)+(0.0000316528.*C_temp_k.^3)+2.*(1-C_xCO2_water_sst_dry_ppm/1e6).^2.*(57.7-0.118.*C_temp_k))./(82.057.*C_temp_k)));
	
	%b. Reported pressures and WOA salt
	pCO2_temp=C_xCO2_water_sst_dry_ppm.*((press-pH2O_woa)./1013.25);						

	fCO2_insitu_from_xCO2_water_sst_dry_ppm_woa=pCO2_temp.*exp((press./1013.25).*((-1636.75+(12.0408.*C_temp_k)...						
	-(0.0327957.*C_temp_k.^2)+(0.0000316528.*C_temp_k.^3)+2.*(1-C_xCO2_water_sst_dry_ppm/1e6).^2.*(57.7-0.118.*C_temp_k))./(82.057.*C_temp_k)));
	
	%c. NCEP pressures & reported salt 
	pCO2_temp=C_xCO2_water_sst_dry_ppm.*((ncep_slp_eq-pH2O)./1013.25);						

	fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep=pCO2_temp.*exp((ncep_slp_eq./1013.25).*((-1636.75+(12.0408.*C_temp_k)...						
	-(0.0327957.*C_temp_k.^2)+(0.0000316528.*C_temp_k.^3)+2.*(1-C_xCO2_water_sst_dry_ppm/1e6).^2.*(57.7-0.118.*C_temp_k))./(82.057.*C_temp_k)));

	%d. NCEP pressures & WOA salt
	pCO2_temp=C_xCO2_water_sst_dry_ppm.*((ncep_slp_eq-pH2O_woa)./1013.25);						

	fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep_woa=pCO2_temp.*exp((ncep_slp_eq./1013.25).*((-1636.75+(12.0408.*C_temp_k)...						
	-(0.0327957.*C_temp_k.^2)+(0.0000316528.*C_temp_k.^3)+2.*(1-C_xCO2_water_sst_dry_ppm/1e6).^2.*(57.7-0.118.*C_temp_k))./(82.057.*C_temp_k)));



%4. from xCO2_water_equi_temp_dry_ppm%%%%%%%%%%%%%%%%%%%%
	
	%a. Reported pressures and salt 
	pCO2_temp=C_xCO2_water_equi_temp_dry_ppm.*((press-pH2O_eq)./1013.25);				

    	fCO2_temp=pCO2_temp.*exp((press./1013.25).*((-1636.75+(12.0408.*C_Temperature_equi_k)...						
	-(0.0327957.*C_Temperature_equi_k.^2)+(0.0000316528.*C_Temperature_equi_k.^3)+2.*(1-C_xCO2_water_equi_temp_dry_ppm/1e6).^2.*(57.7-0.118.*C_Temperature_equi_k))./(82.057.*C_Temperature_equi_k)));
    
	fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm=fCO2_temp.*exp(0.0423.*(C_temp-C_Temperature_equi));

	
	%b.Reported pressures & WOA salt
	pCO2_temp=C_xCO2_water_equi_temp_dry_ppm.*((press-pH2O_eq_woa)./1013.25);				
    
    	fCO2_temp=pCO2_temp.*exp((press./1013.25).*((-1636.75+(12.0408.*C_Temperature_equi_k)...						
	-(0.0327957.*C_Temperature_equi_k.^2)+(0.0000316528.*C_Temperature_equi_k.^3)+2.*(1-C_xCO2_water_equi_temp_dry_ppm/1e6).^2.*(57.7-0.118.*C_Temperature_equi_k))./(82.057.*C_Temperature_equi_k)));
    
	fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_woa=fCO2_temp.*exp(0.0423.*(C_temp-C_Temperature_equi));

		
	%c. NCEP pressures and reported salt
	pCO2_temp=C_xCO2_water_equi_temp_dry_ppm.*((ncep_slp_eq-pH2O_eq)./1013.25);				

     	fCO2_temp=pCO2_temp.*exp((ncep_slp_eq./1013.25).*((-1636.75+(12.0408.*C_Temperature_equi_k)...						
	-(0.0327957.*C_Temperature_equi_k.^2)+(0.0000316528.*C_Temperature_equi_k.^3)+2.*(1-C_xCO2_water_equi_temp_dry_ppm/1e6).^2.*(57.7-0.118.*C_Temperature_equi_k))./(82.057.*C_Temperature_equi_k)));
    
	fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep=fCO2_temp.*exp(0.0423.*(C_temp-C_Temperature_equi));

    
	%d. NCEP pressures and WOA salt 
	pCO2_temp=C_xCO2_water_equi_temp_dry_ppm.*((ncep_slp_eq-pH2O_eq_woa)./1013.25);				

	 fCO2_temp=pCO2_temp.*exp((ncep_slp_eq./1013.25).*((-1636.75+(12.0408.*C_Temperature_equi_k)...						
	-(0.0327957.*C_Temperature_equi_k.^2)+(0.0000316528.*C_Temperature_equi_k.^3)+2.*(1-C_xCO2_water_equi_temp_dry_ppm/1e6).^2.*(57.7-0.118.*C_Temperature_equi_k))./(82.057.*C_Temperature_equi_k)));
    
	fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep_woa=fCO2_temp.*exp(0.0423.*(C_temp-C_Temperature_equi));
	

%5. from fCO2_water_sst_100humidity_uatm%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %these are fCO2 insitu
	fCO2_insitu_from_fCO2_water_sst_100humidty_uatm=C_fCO2_water_sst_100humidity_uatm;


%6. from fCO2_water_corr_25_uatm%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	%not used.

%7. from fCO2_water_corr_to_20%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	%not used.
	
%8. from fCO2_water_equi_uatm%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %convert to SST
	fCO2_insitu_from_fCO2_water_equi_uatm=C_fCO2_water_equi_uatm.*exp(0.0423.*(C_temp-C_Temperature_equi));		


%9. from pCO2_water_sst_100humidity_uatm%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %convert to fCO2 in situ

    %a. Reported pressures
	fCO2_from_pCO2_water_sst_100humidity_uatm=C_pCO2_water_sst_100humidity_uatm.*exp((press./1013.25).*((-1636.75+(12.0408.*C_temp_k)...
	-(0.0327957.*C_temp_k.^2)+(0.0000316528.*C_temp_k.^3)+2.*(1-C_pCO2_water_sst_100humidity_uatm/1e6).^2.*(57.7-0.118.*C_temp_k))./(82.057.*C_temp_k)));	%DOE handboook

	%b.NCEP pressures 
	fCO2_from_pCO2_water_sst_100humidity_uatm_ncep=C_pCO2_water_sst_100humidity_uatm.*exp((ncep_slp_eq./1013.25).*((-1636.75+(12.0408.*C_temp_k)...
	-(0.0327957.*C_temp_k.^2)+(0.0000316528.*C_temp_k.^3)+2.*(1-C_pCO2_water_sst_100humidity_uatm/1e6).^2.*(57.7-0.118.*C_temp_k))./(82.057.*C_temp_k)));	%DOE handboook


%10. from pCO2_water_equi_temp%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	
	%a. Reported pressures
    	fCO2_temp=C_pCO2_water_equi_temp.*exp((press./1013.25).*((-1636.75+(12.0408.*C_Temperature_equi_k)...
	-(0.0327957.*C_Temperature_equi_k.^2)+(0.0000316528.*C_Temperature_equi_k.^3)+2.*(1-C_pCO2_water_equi_temp/1e6).^2.*(57.7-0.118.*C_Temperature_equi_k))./(82.057.*C_Temperature_equi_k)));	%DOE handboook

    
    	fCO2_from_pCO2_water_water_equi_temp=fCO2_temp.*exp(0.0423.*(C_temp-C_Temperature_equi));

	%b. NCEP pressures
	fCO2_temp=C_pCO2_water_equi_temp.*exp((ncep_slp_eq./1013.25).*((-1636.75+(12.0408.*C_Temperature_equi_k)...
	-(0.0327957.*C_Temperature_equi_k.^2)+(0.0000316528.*C_Temperature_equi_k.^3)+2.*(1-C_pCO2_water_equi_temp/1e6).^2.*(57.7-0.118.*C_Temperature_equi_k))./(82.057.*C_Temperature_equi_k)));	%DOE handboook

	fCO2_from_pCO2_water_water_equi_temp_ncep=fCO2_temp.*exp(0.0423.*(C_temp-C_Temperature_equi));



%11. from pCO2_theta_SW_corrected_to_sst%%%%%%%%%%%%%%%%%%%%%%%%%
	%not used


%select recommended fCO2

	fCO2_rec=nan.*ones(length(C_day),1);
	fCO2_source=nan.*ones(length(C_day),1);
	
	index_1=find(isfinite(fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm));
	index_2= find(isfinite(fCO2_insitu_from_xCO2_water_sst_dry_ppm));
	index_3=find(isfinite(fCO2_from_pCO2_water_water_equi_temp));
	index_4=find(isfinite(fCO2_from_pCO2_water_sst_100humidity_uatm));
	index_5=find(isfinite(fCO2_insitu_from_fCO2_water_equi_uatm));
	index_6=find(isfinite(fCO2_insitu_from_fCO2_water_sst_100humidty_uatm));
	index_7=find(isfinite(fCO2_from_pCO2_water_water_equi_temp_ncep));
	index_8=find(isfinite(fCO2_from_pCO2_water_sst_100humidity_uatm_ncep));
	index_9=find(isfinite(fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_woa));
	index_10=find(isfinite(fCO2_insitu_from_xCO2_water_sst_dry_ppm_woa));
	index_11=find(isfinite(fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep));
	index_12=find(isfinite(fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep));
	index_13=find(isfinite(fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep_woa));
	index_14=find(isfinite(fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep_woa));

	fCO2_rec(index_14)=fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep_woa(index_14);
	fCO2_rec(index_13)=fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep_woa(index_13);
	fCO2_rec(index_12)=fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep(index_12);
	fCO2_rec(index_11)=fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep(index_11);
	fCO2_rec(index_10)=fCO2_insitu_from_xCO2_water_sst_dry_ppm_woa(index_10);
	fCO2_rec(index_9) =fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_woa(index_9);
	fCO2_rec(index_8) =fCO2_from_pCO2_water_sst_100humidity_uatm_ncep(index_8);
	fCO2_rec(index_7) =fCO2_from_pCO2_water_water_equi_temp_ncep(index_7);
	fCO2_rec(index_6) =fCO2_insitu_from_fCO2_water_sst_100humidty_uatm(index_6);
	fCO2_rec(index_5) =fCO2_insitu_from_fCO2_water_equi_uatm(index_5);
	fCO2_rec(index_4) =fCO2_from_pCO2_water_sst_100humidity_uatm(index_4);
	fCO2_rec(index_3) =fCO2_from_pCO2_water_water_equi_temp(index_3);
	fCO2_rec(index_2) =fCO2_insitu_from_xCO2_water_sst_dry_ppm(index_2);
	fCO2_rec(index_1) =fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm(index_1);
	
	fCO2_source(index_14)=14;	
	fCO2_source(index_13)=13;	
	fCO2_source(index_12)=12;	
	fCO2_source(index_11)=11;	
	fCO2_source(index_10)=10;	
	fCO2_source(index_9)=9;		
	fCO2_source(index_8)=8;	
	fCO2_source(index_7)=7;	
	fCO2_source(index_6)=6;		
	fCO2_source(index_5)=5;		
	fCO2_source(index_4)=4;		
	fCO2_source(index_3)=3;		
	fCO2_source(index_2)=2;		
	fCO2_source(index_1)=1;		




%%%%%%%Save output

	str=cat(2,eval('finFilesLoc'),eval('files(cr_i).name'),'.txt')

	fid = fopen(eval('str'),'w');
	
	hdr=cat(2, 'sta\ttype\tmon\tday\tyr\thh\tmm\tss\tlong\tlat\tbottomD\tdepth\t',...
	'temp\tsal\t',...
	'xCO2_water_sst_dry_ppm\txCO2_water_equi_temp_dry_ppm\tfCO2_water_sst_100humidity_uatm\t',...
	'fCO2_water_equi_uatm\t',...
	'pCO2_water_sst_100humidity_uatm\tpCO2_water_equi_temp\t',...
	'Temperature_equi\tPressure_atm\t',...
	'Pressure_equi\twind_direc_true\twind_direc_rel\twind_speed_true\twind_speed_rel\tship_speed\tship_direc\t',...
	'Humidity\txCO2_atm\tfCO2_atm\tpCO2_atm\tdfCO2\tdpCO2\twoa_sss\twoa_land_marker\tncep_slp\tspeed_calc_knots\tETOPO2\t',...
	'fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm\tfCO2_insitu_from_xCO2_water_sst_dry_ppm\t',...
	'fCO2_from_pCO2_water_water_equi_temp\tfCO2_from_pCO2_water_sst_100humidity_uatm\t',...
	'fCO2_insitu_from_fCO2_water_equi_uatm\tfCO2_insitu_from_fCO2_water_sst_100humidty_uatm\t',...'
	'fCO2_from_pCO2_water_water_equi_temp_ncep\tfCO2_from_pCO2_water_sst_100humidity_uatm_ncep\t',...
	'fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_woa\tfCO2_insitu_from_xCO2_water_sst_dry_ppm_woa\t',...
	'fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep\tfCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep\t',...
	'fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep_woa\t',...
	'fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep_woa\tfCO2_rec\tfCO2_source\n');
	

	fprintf(fid,eval('hdr'));
	
	form_outStr=cat(2,'%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t',...
	 '%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t',...
	  '%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%f\t%f\t%f\t%f\t%f\t%f\t',...
	   '%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\t%f\n');
	
	
	
	for i =1: length(press);

		wr_sta=sta{i};
		wr_type=type{i};
		wr_mon=mon{i};
		wr_day=day{i};
		wr_yr=yr{i};
		wr_hh=hh{i};
		wr_mm=mm{i};
        wr_ss=ss{i};
		wr_long=long{i};
		wr_lat=lat{i};
		wr_bottomD=bottomD{i}; 
		wr_depth=depth{i};
		wr_temp=temp{i}; 
		wr_sal=sal{i}; 
		wr_xCO2_water_sst_dry_ppm=xCO2_water_sst_dry_ppm{i};
		wr_xCO2_water_equi_temp_dry_ppm=xCO2_water_equi_temp_dry_ppm{i}; 
		wr_fCO2_water_sst_100humidity_uatm=fCO2_water_sst_100humidity_uatm{i};
		wr_fCO2_water_equi_uatm=fCO2_water_equi_uatm{i};
		wr_pCO2_water_sst_100humidity_uatm=pCO2_water_sst_100humidity_uatm{i};
		wr_pCO2_water_equi_temp=pCO2_water_equi_temp{i};
		wr_Temperature_equi=Temperature_equi{i};
		wr_Pressure_atm=Pressure_atm{i};
		wr_Pressure_equi=Pressure_equi{i};
		wr_wind_direc_true=wind_direc_true{i};
        wr_wind_direc_rel=wind_direc_rel{i};
		wr_wind_speed_true=wind_speed_true{i};
        wr_wind_speed_rel=wind_speed_rel{i};
		wr_ship_speed=ship_speed{i}; 
		wr_ship_direc=ship_direc{i}; 
		wr_Humidity=Humidity{i};
        wr_xCO2_atm=xCO2_atm{i};
        wr_fCO2_atm=fCO2_atm{i};
        wr_pCO2_atm=pCO2_atm{i};
        wr_dfCO2=dfCO2{i};
        wr_dpCO2=dpCO2{i};
		
        
        fprintf(fid,eval('form_outStr'),...
		wr_sta, wr_type, wr_mon, wr_day, wr_yr, wr_hh, wr_mm, wr_ss,wr_long, wr_lat, wr_bottomD, wr_depth, wr_temp,...
 		wr_sal, wr_xCO2_water_sst_dry_ppm,...
  		wr_xCO2_water_equi_temp_dry_ppm,...
  		wr_fCO2_water_sst_100humidity_uatm, ...
    	wr_fCO2_water_equi_uatm,...
    	wr_pCO2_water_sst_100humidity_uatm, wr_pCO2_water_equi_temp,....
    	wr_Temperature_equi, wr_Pressure_atm,...
    	wr_Pressure_equi, wr_wind_direc_true,wr_wind_direc_rel, wr_wind_speed_true,wr_wind_speed_rel,...
           wr_ship_speed, wr_ship_direc, wr_Humidity,wr_xCO2_atm, wr_fCO2_atm, wr_pCO2_atm, wr_dfCO2, wr_dpCO2,...
		woa_sss(i), woa_land_marker(i), ncep_slp(i),speed(i),z_out(i),fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm(i), fCO2_insitu_from_xCO2_water_sst_dry_ppm(i),...
		fCO2_from_pCO2_water_water_equi_temp(i), fCO2_from_pCO2_water_sst_100humidity_uatm(i),...
		fCO2_insitu_from_fCO2_water_equi_uatm(i),fCO2_insitu_from_fCO2_water_sst_100humidty_uatm(i),...
		fCO2_from_pCO2_water_water_equi_temp_ncep(i), fCO2_from_pCO2_water_sst_100humidity_uatm_ncep(i),...
		fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_woa(i),...
		fCO2_insitu_from_xCO2_water_sst_dry_ppm_woa(i),...
		fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep(i),...
		fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep(i),...
		fCO2_insitu_from_xCO2_water_equi_temp_dry_ppm_ncep_woa(i),...
		fCO2_insitu_from_xCO2_water_sst_dry_ppm_ncep_woa(i),fCO2_rec(i), fCO2_source(i));
   	end
	
	fclose(fid);
end
cd .. %back to parent directory
